@@ -14,24 +14,18 @@
  *           where apbs.in is a formatted input file (see documentation and
  *           examples).
  * 
- *  @version $Id: main.c 1460 2009-11-23 22:29:03Z yhuang01 $
+ *  @version $Id: main.c 1615 2010-10-20 19:16:35Z sobolevnrm $
  *  @attention
  *  @verbatim
  *
  * APBS -- Adaptive Poisson-Boltzmann Solver
  *
- * Nathan A. Baker (baker@biochem.wustl.edu)
- * Dept. of Biochemistry and Molecular Biophysics
- * Center for Computational Biology
- * Washington University in St. Louis
+ * Nathan A. Baker (nathan.baker@pnl.gov)
+ * Pacific Northwest National Laboratory
  *
  * Additional contributing authors listed in the code documentation.
  *
- * Copyright (c) 2002-2009, Washington University in St. Louis.
- * Portions Copyright (c) 2002-2009.  Nathan A. Baker
- * Portions Copyright (c) 1999-2002.  The Regents of the University of California.
- * Portions Copyright (c) 1995.  Michael Holst
- *
+ * Copyright (c) 2010, Pacific Northwest National Laboratory.  Portions Copyright (c) 2002-2010, Washington University in St. Louis.  Portions Copyright (c) 2002-2010, Nathan A. Baker.  Portions Copyright (c) 1999-2002, The Regents of the University of California. Portions Copyright (c) 1995, Michael Holst.
  * All rights reserved.
  * 
  * Redistribution and use in source and binary forms, with or without
@@ -73,7 +67,7 @@
 
 #include "routines.h"
 
-VEMBED(rcsid="$Id: main.c 1460 2009-11-23 22:29:03Z yhuang01 $")
+VEMBED(rcsid="$Id: main.c 1615 2010-10-20 19:16:35Z sobolevnrm $")
 
 /** 
  * @brief The main APBS function
@@ -111,6 +105,7 @@ int main(
 	Valist *alist[NOSH_MAXMOL];
 	Vgrid *dielXMap[NOSH_MAXMOL],*dielYMap[NOSH_MAXMOL],*dielZMap[NOSH_MAXMOL];
 	Vgrid *kappaMap[NOSH_MAXMOL];
+	Vgrid *potMap[NOSH_MAXMOL];
 	Vgrid *chargeMap[NOSH_MAXMOL];
 	char *input_path = VNULL;
 	char *output_path = VNULL;
@@ -141,20 +136,14 @@ int main(
 	char header[] = {"\n\n\
 ----------------------------------------------------------------------\n\
 	APBS -- Adaptive Poisson-Boltzmann Solver\n\
-	Version 1.2.1\n\
+	Version 1.3\n\
 	\n\
-	Nathan A. Baker (baker@biochem.wustl.edu)\n\
-	Dept. Biochemistry and Molecular Biophysics\n\
-	Center for Computational Biology\n\
+	Nathan A. Baker (nathan.baker@pnl.gov)\n\
 	Washington University in St. Louis\n\
 	\n\
 	Additional contributing authors listed in the code documentation.\n\
 	\n\
-	Copyright (c) 2002-2009, Washington University in St. Louis.\n\
-	Portions Copyright (c) 2002-2009.  Nathan A. Baker\n\
-	Portions Copyright (c) 1999-2002.  The Regents of the University of California.\n\
-	Portions Copyright (c) 1995.  Michael Holst\n\
-	\n\
+	Copyright (c) 2010, Pacific Northwest National Laboratory.  Portions Copyright (c) 2002-2010, Washington University in St. Louis.  Portions Copyright (c) 2002-2010, Nathan A. Baker.  Portions Copyright (c) 1999-2002, The Regents of the University of California. Portions Copyright (c) 1995, Michael Holst.\n\
 	All rights reserved.\n\
 	\n\
 	Redistribution and use in source and binary forms, with or without\n\
@@ -250,6 +239,7 @@ int main(
 		dielYMap[i] = VNULL;
 		dielZMap[i] = VNULL;
 		kappaMap[i] = VNULL;
+		potMap[i] = VNULL;
 		chargeMap[i] = VNULL;
 	}
 
@@ -266,6 +256,12 @@ int main(
 
 	Vnm_tprint( 1, "This executable compiled on %s at %s\n\n", __DATE__, __TIME__);
 
+#if defined(WITH_TINKER)
+	Vnm_tprint( 2, "This executable was compiled with TINKER support and is not intended for stand-alone execution.\n");
+	Vnm_tprint( 2, "Please compile another version without TINKER support.\n");
+	exit(2);
+#endif
+	
 	i=0;
 	outputformat = OUTPUT_NULL;
 	while (i<argc){
@@ -279,7 +275,10 @@ int main(
 				Vnm_tprint(2, "%s\n", usage);
 				VJMPERR1(0); 
 			} else if (strncmp(argv[i], "--output-format", 15) == 0) {
-				if (strstr(argv[i], "xml") != NULL) outputformat = OUTPUT_XML;
+				if (strstr(argv[i], "xml") != NULL) {
+					Vnm_tprint(2, "XML output format is now deprecated, please use --output-format=flat instead!\n\n");
+					VJMPERR1(0); 
+				}
 				else if (strstr(argv[i], "flat") != NULL) {
 					outputformat = OUTPUT_FLAT;
 				} else {
@@ -363,7 +362,26 @@ int main(
 	 	VJMPERR1(0);
 	} */
 	
-#if defined(DEBUG_MAC_OSX)	
+#if defined(DEBUG_MAC_OSX_OCL)
+#include "mach_chud.h"
+#include <stdint.h>
+	uint64_t mbeg;
+	machm_(&mbeg);
+	
+	if(clFinish != NULL)
+	{
+		int ret = initOpenCL();
+        printf("OpenCL runtime present - initialized = %i\n",ret);
+    }
+    else
+	{
+		setkOpenCLAvailable_(0);
+        printf("OpenCL is not present!\n");
+	}
+#endif
+	
+#if defined(DEBUG_MAC_OSX_STANDARD)
+#include "mach_chud.h"
 #include <stdint.h>
 	uint64_t mbeg;
 	machm_(&mbeg);
@@ -378,6 +396,10 @@ int main(
 		Vnm_tprint(2, "Error reading kappa maps!\n");
 		VJMPERR1(0);
 	}
+	if (loadPotMaps(nosh, potMap) != 1) {
+		Vnm_tprint(2, "Error reading potential maps!\n");
+		VJMPERR1(0);
+	}
 	if (loadChargeMaps(nosh, chargeMap) != 1) {
 		Vnm_tprint(2, "Error reading charge maps!\n");
 		VJMPERR1(0);
@@ -410,13 +432,14 @@ int main(
 				
 				/* Set up problem */
 				Vnm_tprint( 1, "  Setting up problem...\n");
+
 				if (!initMG(i, nosh, mgparm, pbeparm, realCenter, pbe, 
-							alist, dielXMap, dielYMap, dielZMap, kappaMap, chargeMap, 
-							pmgp, pmg)) {
+							alist, dielXMap, dielYMap, dielZMap, kappaMap,
+							chargeMap, pmgp, pmg, potMap)) {
 					Vnm_tprint( 2, "Error setting up MG calculation!\n");
 					VJMPERR1(0);
 				}
-				
+
 				/* Print problem parameters */
 				printMGPARM(mgparm, realCenter);
 				printPBEPARM(pbeparm);
@@ -441,7 +464,7 @@ int main(
 				/* Write out forces */
 				forceMG(mem, nosh, pbeparm, mgparm, pmg[i], &(nforce[i]), 
 						&(atomForce[i]), alist);
-				
+					
 				/* Write out data folks might want */
 				writedataMG(rank, nosh, pbeparm, pmg[i]);
 				
@@ -604,12 +627,7 @@ int main(
 	
 	/* *************** HANDLE LOGGING *********************** */
 
-	if (outputformat == OUTPUT_XML) {
-		Vnm_tprint(2, "  Writing data to XML file %s...\n\n", output_path);
-		writedataXML(nosh, com, output_path, totEnergy, qfEnergy, qmEnergy,
-					 dielEnergy, nenergy, atomEnergy, nforce, atomForce);
-		
-	} else if (outputformat == OUTPUT_FLAT) {
+	if (outputformat == OUTPUT_FLAT) {
 		Vnm_tprint(2," Writing data to flat file %s...\n\n", output_path);
 		writedataFlat(nosh, com, output_path, totEnergy, qfEnergy, qmEnergy,
 					  dielEnergy, nenergy, atomEnergy, nforce, atomForce);
@@ -621,7 +639,7 @@ int main(
 		if (nenergy[i] > 0) Vmem_free(mem, nenergy[i], sizeof(double),
 									  (void **)&(atomEnergy[i]));    
 	}
-
+	
 	/* *************** GARBAGE COLLECTION ******************* */
 
 	Vnm_tprint( 1, "CLEANING UP AND SHUTTING DOWN...\n");
@@ -653,8 +671,11 @@ int main(
 	Vnm_tprint(1, "\n\n");
 	Vnm_tprint( 1, "Thanks for using APBS!\n\n");
 
-#if defined(DEBUG_MAC_OSX)
-	mets_(&mbeg, "main program");
+#if defined(DEBUG_MAC_OSX_OCL)
+	mets_(&mbeg, "Main Program CL");
+#endif
+#if defined(DEBUG_MAC_OSX_STANDARD)
+	mets_(&mbeg, "Main Program Standard");
 #endif
 	
 	/* This should be last */
