@@ -3,24 +3,18 @@
  *  @ingroup Vfetk
  *  @author  Nathan Baker
  *  @brief   Class Vfetk methods
- *  @version $Id: vfetk.c 1490 2009-12-01 14:17:28Z sdg0919 $
+ *  @version $Id: vfetk.c 1615 2010-10-20 19:16:35Z sobolevnrm $
  *  @attention
  *  @verbatim
  *
  * APBS -- Adaptive Poisson-Boltzmann Solver
  *
- * Nathan A. Baker (baker@biochem.wustl.edu)
- * Dept. of Biochemistry and Molecular Biophysics
- * Center for Computational Biology
- * Washington University in St. Louis
+ * Nathan A. Baker (nathan.baker@pnl.gov)
+ * Pacific Northwest National Laboratory
  *
  * Additional contributing authors listed in the code documentation.
  *
- * Copyright (c) 2002-2009, Washington University in St. Louis.
- * Portions Copyright (c) 2002-2009.  Nathan A. Baker
- * Portions Copyright (c) 1999-2002.  The Regents of the University of California.
- * Portions Copyright (c) 1995.  Michael Holst
- *
+ * Copyright (c) 2010, Pacific Northwest National Laboratory.  Portions Copyright (c) 2002-2010, Washington University in St. Louis.  Portions Copyright (c) 2002-2010, Nathan A. Baker.  Portions Copyright (c) 1999-2002, The Regents of the University of California. Portions Copyright (c) 1995, Michael Holst.
  * All rights reserved.
  * 
  * Redistribution and use in source and binary forms, with or without
@@ -619,7 +613,7 @@ VPUBLIC void Vfetk_setParameters(Vfetk *thee, PBEparm *pbeparm,
 VPUBLIC void Vfetk_dtor(Vfetk **thee) {
     if ((*thee) != VNULL) {
         Vfetk_dtor2(*thee);
-        Vmem_free(VNULL, 1, sizeof(Vfetk), (void **)thee);
+        //Vmem_free(VNULL, 1, sizeof(Vfetk), (void **)thee);
         (*thee) = VNULL;
     }
 }
@@ -1166,7 +1160,12 @@ VPUBLIC void Vfetk_PDE_dtor(PDE **thee) {
 
     if ((*thee) != VNULL) {
         Vfetk_PDE_dtor2(*thee);
-        Vmem_free(var.fetk->vmem, 1, sizeof(PDE), (void **)thee);
+		/* TODO: The following line is commented out because at the moment,
+			there is a seg fault when deallocating at the end of a run. Since
+			this routine is called only once at the very end, we'll leave it
+			commented out. However, this could be a memory leak.
+		 */
+        /* Vmem_free(var.fetk->vmem, 1, sizeof(PDE), (void **)thee); */
         (*thee) = VNULL;
     }
 
