@@ -10,7 +10,7 @@
  *  @file       vpbe.h
  *  @ingroup    Vpbe
  *  @brief      Contains declarations for class Vpbe
- *  @version  $Id: vpbe.h 1389 2009-08-19 17:21:23Z sdg0919 $
+ *  @version  $Id: vpbe.h 1615 2010-10-20 19:16:35Z sobolevnrm $
  *  @author   Nathan A. Baker
  *
  *  @attention
@@ -18,18 +18,12 @@
  *
  * APBS -- Adaptive Poisson-Boltzmann Solver
  *
- * Nathan A. Baker (baker@biochem.wustl.edu)
- * Dept. of Biochemistry and Molecular Biophysics
- * Center for Computational Biology
- * Washington University in St. Louis
+ * Nathan A. Baker (nathan.baker@pnl.gov)
+ * Pacific Northwest National Laboratory
  *
  * Additional contributing authors listed in the code documentation.
  *
- * Copyright (c) 2002-2009, Washington University in St. Louis.
- * Portions Copyright (c) 2002-2009.  Nathan A. Baker
- * Portions Copyright (c) 1999-2002.  The Regents of the University of California.
- * Portions Copyright (c) 1995.  Michael Holst
- *
+ * Copyright (c) 2010, Pacific Northwest National Laboratory.  Portions Copyright (c) 2002-2010, Washington University in St. Louis.  Portions Copyright (c) 2002-2010, Nathan A. Baker.  Portions Copyright (c) 1999-2002, The Regents of the University of California. Portions Copyright (c) 1995, Michael Holst.
  * All rights reserved.
  * 
  * Redistribution and use in source and binary forms, with or without
@@ -126,11 +120,11 @@ struct sVpbe {
 	/* Added by Michael Grabe                                */
 	/*-------------------------------------------------------*/
 	
-	double z_mem;        /* Z value of the botton of the membrane (A) */
-	double L;            /* Length of the membrane (A) */
-	double membraneDiel; /* Membrane dielectric constant */
-	double V;            /* Membrane potential */
-	int param2Flag;     /* Check to see if bcfl=3 parms have been set */
+	double z_mem;        /**< Z value of the botton of the membrane (A) */
+	double L;            /**< Length of the membrane (A) */
+	double membraneDiel; /**< Membrane dielectric constant */
+	double V;            /**< Membrane potential */
+	int param2Flag;     /**< Check to see if bcfl=3 parms have been set */
 	/*-------------------------------------------------------*/
 	
 };
@@ -376,7 +370,7 @@ VEXTERNC double  Vpbe_getmemv(Vpbe *thee);
 
 /** @brief   Construct Vpbe object
 *  @ingroup Vpbe
-*  @author  Nathan Baker and Mike Holst
+*  @author  Nathan Baker and Mike Holst and Michael Grabe
 *  @note   This is partially based on some of Mike Holst's PMG code.  Here
 *           are a few of the original function comments:
 *           kappa is defined as follows:
@@ -392,33 +386,29 @@ VEXTERNC double  Vpbe_getmemv(Vpbe *thee);
 *           angstroms^2, noting that the 1000 in the denominator has converted
 *           m^3 to cm^3, since the ionic strength \f$I_s\f$ is assumed to have
 *           been provided in moles per liter, which is moles per 1000 cm^3.
-*  @param   alist  Atom list
-*  @param   ionNum  Number of counterion species
-*  @param   ionConc Array containing counterion species' concentrations (M)
-*  @param   ionRadii Array containing counterion species' radii (A)
-*  @param   ionQ Array containing counterion species' charges (e)
-*  @param   T temperature (K)
-*  @param   soluteDiel Solute dielectric constant
-*  @param   solventDiel Solvent dielectric constant
-*  @param   solventRadius Solvent radius
-*  @param   focusFlag 1 if Focusing operation, 0 otherwise
-*  @param   sdens Vacc sphere density
 *  @return  Pointer to newly allocated Vpbe object
 */
-
-/*---------------------------------------------------------------*/
-/* Additions by Michael Grabe to Vpbe_ctor2 and Vpbe_ctor        */
-/*---------------------------------------------------------------*/
-
-VEXTERNC Vpbe*   Vpbe_ctor(Valist *alist, int ionNum, double *ionConc, 
-						   double *ionRadii, double *ionQ, double T, 
-						   double soluteDiel, double solventDiel,  
-						   double solventRadius, int focusFlag, double sdens,
-						   double z_mem, double L, double membraneDiel, double V);
+VEXTERNC Vpbe*   Vpbe_ctor(
+							Valist *alist, /**< Atom list */
+							int ionNum, /**< Number of counterion species */
+							double *ionConc, /**< Array containing counterion concentrations (M) */
+						  	double *ionRadii, /**< Array containing counterion radii (A) */
+							double *ionQ, /**< Array containing counterion charges (e) */
+							double T, /**< Temperature for Boltzmann distribution (K) */
+							double soluteDiel, /**< Solute internal dielectric constant */
+							double solventDiel,  /**< Solvent dielectric constant */
+							double solventRadius, /**< Solvent probe radius for surfaces that use it (A) */
+							int focusFlag, /**< 1 if focusing operation, 0 otherwise */
+							double sdens,  /**< Vacc sphere density */
+							double z_mem, /**< Membrane location (A) */
+							double L, /**< Membrane thickness (A) */
+							double membraneDiel, /**< Membrane dielectric constant */
+							double V /**< Transmembrane potential (V) */
+							);
 
 /** @brief   FORTRAN stub to construct Vpbe objct
  *  @ingroup Vpbe
- *  @author  Nathan Baker and Mike Holst
+ *  @author  Nathan Baker and Mike Holst and Michael Grabe
  *  @note   This is partially based on some of Mike Holst's PMG code.  Here
  *           are a few of the original function comments:
  *           kappa is defined as follows:
@@ -433,27 +423,27 @@ VEXTERNC Vpbe*   Vpbe_ctor(Valist *alist, int ionNum, double *ionConc,
  *           angstroms^2, noting that the 1000 in the denominator has converted
  *           m^3 to cm^3, since the ionic strength \f$I_s\f$ is assumed to have
  *           been provided in moles per liter, which is moles per 1000 cm^3. 
- *  @param   thee   Pointer to memory allocated for Vpbe object
- *  @param   alist  Atom list
- *  @param   ionNum  Number of counterion species
- *  @param   ionConc Array containing counterion species' concentrations (M)
- *  @param   ionRadii Array containing counterion species' radii (A)
- *  @param   ionQ Array containing counterion species' charges (e)
- *  @param   T temperature (K)
- *  @param   soluteDiel Solute dielectric constant
- *  @param   solventDiel Solvent dielectric constant
- *  @param   solventRadius Solvent radius
- *  @param   focusFlag 1 if Focusing operation, 0 otherwise
  *  @bug     The focusing flag is currently not used!!
- *  @param   sdens Vacc sphere density
  *  @return  1 if successful, 0 otherwise
  */
-VEXTERNC int    Vpbe_ctor2(Vpbe *thee, Valist *alist, int ionNum, 
-						   double *ionConc, double *ionRadii, double *ionQ, 
-						   double T, double soluteDiel, 
-						   double solventDiel, double solventRadius, int focusFlag,
-						   double sdens, double z_mem, double L, double membraneDiel, 
-						   double V);
+VEXTERNC int    Vpbe_ctor2(
+							Vpbe *thee, /**< Pointer to memory allocated for Vpbe object */
+							Valist *alist, /**< Atom list */
+							int ionNum, /**< Number of counterion species */
+							double *ionConc, /**< Array containing counterion concentrations (M) */
+							double *ionRadii, /**< Array containing counterion radii (A) */
+							double *ionQ, /**< Array containing counterion charges (e) */
+							double T, /**< Temperature for Boltzmann distribution (K) */
+							double soluteDiel, /**< Solute internal dielectric constant */
+							double solventDiel,  /**< Solvent dielectric constant */
+							double solventRadius, /**< Solvent probe radius for surfaces that use it (A) */
+							int focusFlag, /**< 1 if focusing operation, 0 otherwise */
+							double sdens,  /**< Vacc sphere density */
+							double z_mem, /**< Membrane location (A) */
+							double L, /**< Membrane thickness (A) */
+							double membraneDiel, /**< Membrane dielectric constant */
+							double V /**< Transmembrane potential (V) */
+							);
 
 /** @brief   Get information about the counterion species present
 *  @ingroup Vpbe
