@@ -3,24 +3,18 @@
  *  @ingroup MGparm
  *  @author  Nathan Baker
  *  @brief   Class MGparm methods
- *  @version $Id: mgparm.c 1350 2009-02-12 00:38:48Z yhuang01 $
+ *  @version $Id: mgparm.c 1615 2010-10-20 19:16:35Z sobolevnrm $
  *  @attention
  *  @verbatim
  *
  * APBS -- Adaptive Poisson-Boltzmann Solver
  *
- * Nathan A. Baker (baker@biochem.wustl.edu)
- * Dept. of Biochemistry and Molecular Biophysics
- * Center for Computational Biology
- * Washington University in St. Louis
+ * Nathan A. Baker (nathan.baker@pnl.gov)
+ * Pacific Northwest National Laboratory
  *
  * Additional contributing authors listed in the code documentation.
  *
- * Copyright (c) 2002-2009, Washington University in St. Louis.
- * Portions Copyright (c) 2002-2009.  Nathan A. Baker
- * Portions Copyright (c) 1999-2002.  The Regents of the University of California.
- * Portions Copyright (c) 1995.  Michael Holst
- *
+ * Copyright (c) 2010, Pacific Northwest National Laboratory.  Portions Copyright (c) 2002-2010, Washington University in St. Louis.  Portions Copyright (c) 2002-2010, Nathan A. Baker.  Portions Copyright (c) 1999-2002, The Regents of the University of California. Portions Copyright (c) 1995, Michael Holst.
  * All rights reserved.
  * 
  * Redistribution and use in source and binary forms, with or without
@@ -58,7 +52,7 @@
 #include "apbs/mgparm.h"
 #include "apbs/vstring.h"
 
-VEMBED(rcsid="$Id: mgparm.c 1350 2009-02-12 00:38:48Z yhuang01 $")
+VEMBED(rcsid="$Id: mgparm.c 1615 2010-10-20 19:16:35Z sobolevnrm $")
 
 #if !defined(VINLINE_MGPARM)
 
@@ -145,6 +139,8 @@ VPUBLIC Vrc_Codes MGparm_ctor2(MGparm *thee, MGparm_CalcType type) {
     /* *** TYPE 0 PARAMETERS *** */
     thee->nlev = VMGNLEV;
     thee->setnlev = 1;
+    thee->etol = 1.0e-6;
+    thee->setetol = 0;
     thee->setgrid = 0;
     thee->setglen = 0;
     thee->setgcent = 0;  
@@ -359,6 +355,8 @@ VPUBLIC void MGparm_copy(MGparm *thee, MGparm *parm) {
     /* *** TYPE 0 PARMS *** */
     thee->nlev = parm->nlev;
     thee->setnlev = parm->setnlev;
+    thee->etol = parm->etol;
+    thee->setetol = parm->setetol;
     for (i=0; i<3; i++) thee->grid[i] = parm->grid[i];
     thee->setgrid = parm->setgrid;
     for (i=0; i<3; i++) thee->glen[i] = parm->glen[i];
@@ -511,6 +509,29 @@ keyword!\n", tok);
         return VRC_WARNING;
 }
 
+VPRIVATE Vrc_Codes MGparm_parseETOL(MGparm *thee, Vio *sock) {
+
+    char tok[VMAX_BUFSIZE];
+    double tf;
+
+    VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
+    if (sscanf(tok, "%lf", &tf) == 0) {
+        Vnm_print(2, "NOsh:  Read non-float (%s) while parsing etol \
+keyword!\n", tok);
+        return VRC_WARNING;
+    } else if (tf <= 0.0) {
+        Vnm_print(2, "parseMG:  etol must be greater than 0!\n");
+        return VRC_WARNING;
+    } else thee->etol = tf;
+    thee->setetol = 1;
+    return VRC_SUCCESS;
+
+    VERROR1:
+        Vnm_print(2, "parseMG:  ran out of tokens!\n");
+        return VRC_WARNING;
+}
+
+
 VPRIVATE Vrc_Codes MGparm_parseGRID(MGparm *thee, Vio *sock) {
 
     char tok[VMAX_BUFSIZE];
@@ -911,7 +932,10 @@ VPUBLIC Vrc_Codes MGparm_parseToken(MGparm *thee, char tok[VMAX_BUFSIZE],
     } else if (Vstring_strcasecmp(tok, "chgm") == 0) {
         return MGparm_parseCHGM(thee, sock);
     } else if (Vstring_strcasecmp(tok, "nlev") == 0) {
+        Vnm_print(2, "Warning: The 'nlev' keyword is now deprecated!\n");
         return MGparm_parseNLEV(thee, sock);
+    } else if (Vstring_strcasecmp(tok, "etol") == 0) {
+        return MGparm_parseETOL(thee, sock);
     } else if (Vstring_strcasecmp(tok, "grid") == 0) {
         return MGparm_parseGRID(thee, sock);
     } else if (Vstring_strcasecmp(tok, "glen") == 0) {
