@@ -3,24 +3,18 @@
  *  @ingroup NOsh
  *  @author  Nathan Baker
  *  @brief   Class NOsh methods
- *  @version $Id: nosh.c 1350 2009-02-12 00:38:48Z yhuang01 $
+ *  @version $Id: nosh.c 1615 2010-10-20 19:16:35Z sobolevnrm $
  *  @attention
  *  @verbatim
  *
  * APBS -- Adaptive Poisson-Boltzmann Solver
  *
- * Nathan A. Baker (baker@biochem.wustl.edu)
- * Dept. of Biochemistry and Molecular Biophysics
- * Center for Computational Biology
- * Washington University in St. Louis
+ * Nathan A. Baker (nathan.baker@pnl.gov)
+ * Pacific Northwest National Laboratory
  *
  * Additional contributing authors listed in the code documentation.
  *
- * Copyright (c) 2002-2009, Washington University in St. Louis.
- * Portions Copyright (c) 2002-2009.  Nathan A. Baker
- * Portions Copyright (c) 1999-2002.  The Regents of the University of California.
- * Portions Copyright (c) 1995.  Michael Holst
- *
+ * Copyright (c) 2010, Pacific Northwest National Laboratory.  Portions Copyright (c) 2002-2010, Washington University in St. Louis.  Portions Copyright (c) 2002-2010, Nathan A. Baker.  Portions Copyright (c) 1999-2002, The Regents of the University of California. Portions Copyright (c) 1995, Michael Holst.
  * All rights reserved.
  * 
  * Redistribution and use in source and binary forms, with or without
@@ -59,7 +53,7 @@
 #include "apbs/mgparm.h"
 #include "apbs/femparm.h"
 
-VEMBED(rcsid="$Id: nosh.c 1350 2009-02-12 00:38:48Z yhuang01 $")
+VEMBED(rcsid="$Id: nosh.c 1615 2010-10-20 19:16:35Z sobolevnrm $")
 
 
 VPRIVATE int NOsh_parseREAD(
@@ -160,6 +154,11 @@ VPUBLIC char* NOsh_getKappapath(NOsh *thee, int imol) {
 	VASSERT(imol < thee->nmol);
 	return thee->kappapath[imol];
 }
+VPUBLIC char* NOsh_getPotpath(NOsh *thee, int imol) {
+	VASSERT(thee != VNULL);
+	VASSERT(imol < thee->nmol);
+	return thee->potpath[imol];
+}
 VPUBLIC char* NOsh_getChargepath(NOsh *thee, int imol) {
 	VASSERT(thee != VNULL);
 	VASSERT(imol < thee->nmol);
@@ -180,6 +179,11 @@ VPUBLIC int NOsh_getKappafmt(NOsh *thee, int i) {
 	VASSERT(i < thee->nkappa);
 	return (thee->kappafmt[i]);
 }
+VPUBLIC int NOsh_getPotfmt(NOsh *thee, int i) {
+	VASSERT(thee != VNULL);
+	VASSERT(i < thee->npot);
+	return (thee->potfmt[i]);
+}
 VPUBLIC int NOsh_getChargefmt(NOsh *thee, int i) {
 	VASSERT(thee != VNULL);
 	VASSERT(i < thee->ncharge);
@@ -261,6 +265,7 @@ VPUBLIC int NOsh_ctor2(NOsh *thee, int rank, int size) {
     thee->ncharge = 0;
     thee->ndiel = 0;
     thee->nkappa = 0;
+	thee->npot = 0;
     thee->nprint = 0;
 	
     for (i=0; i<NOSH_MAXCALC; i++) {
@@ -451,8 +456,8 @@ VPUBLIC int NOsh_parseInput(
 			Vnm_print(0, "NOsh: Parsing READ section\n");
 			if (!NOsh_parseREAD(thee, sock)) return 0;
 			Vnm_print(0, "NOsh: Done parsing READ section \
-(nmol=%d, ndiel=%d, nkappa=%d, ncharge=%d)\n", thee->nmol, thee->ndiel, 
-					  thee->nkappa, thee->ncharge);
+(nmol=%d, ndiel=%d, nkappa=%d, ncharge=%d, npot=%d)\n", thee->nmol, thee->ndiel, 
+					  thee->nkappa, thee->ncharge,thee->npot);
 		} else if (Vstring_strcasecmp(tok, "print") == 0) {
 			Vnm_print(0, "NOsh: Parsing PRINT section\n");
 			if (!NOsh_parsePRINT(thee, sock)) return 0;
@@ -629,37 +634,41 @@ VPRIVATE int NOsh_parseREAD_DIEL(NOsh *thee, Vio *sock) {
     VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
     if (Vstring_strcasecmp(tok, "dx") == 0) {
         dielfmt = VDF_DX;
-        VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
-        if (tok[0]=='"') {
-            strcpy(strnew, "");
-            while (tok[strlen(tok)-1] != '"') {
-                strcat(str, tok);
-                strcat(str, " ");
-                VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
-			}
-            strcat(str, tok);
-            strncpy(strnew, str+1, strlen(str)-2);
-            strcpy(tok, strnew);
-        }
-        Vnm_print(0, "NOsh: Storing x-shifted dielectric map %d path \
-%s\n", thee->ndiel, tok);
-        strncpy(thee->dielXpath[thee->ndiel], tok, VMAX_ARGLEN);
-        VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
-        Vnm_print(0, "NOsh: Storing y-shifted dielectric map %d path \
-%s\n", thee->ndiel, tok);
-        strncpy(thee->dielYpath[thee->ndiel], tok, VMAX_ARGLEN);
-        VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
-        Vnm_print(0, "NOsh: Storing z-shifted dielectric map %d path \
-%s\n", thee->ndiel, tok);
-        strncpy(thee->dielZpath[thee->ndiel], tok, VMAX_ARGLEN);
-        thee->dielfmt[thee->ndiel] = dielfmt;
-        (thee->ndiel)++;
-    } else { 
+	} else if (Vstring_strcasecmp(tok, "gz") == 0) {
+        dielfmt = VDF_GZ;
+	} else {
         Vnm_print(2, "NOsh_parseREAD:  Ignoring undefined format \
-%s!\n", tok);
-    } 
+				  %s!\n", tok);
+		return VRC_FAILURE;
+	}
 	
-    return 1;
+	VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
+	if (tok[0]=='"') {
+		strcpy(strnew, "");
+		while (tok[strlen(tok)-1] != '"') {
+			strcat(str, tok);
+			strcat(str, " ");
+			VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
+		}
+		strcat(str, tok);
+		strncpy(strnew, str+1, strlen(str)-2);
+		strcpy(tok, strnew);
+	}
+	Vnm_print(0, "NOsh: Storing x-shifted dielectric map %d path \
+			  %s\n", thee->ndiel, tok);
+	strncpy(thee->dielXpath[thee->ndiel], tok, VMAX_ARGLEN);
+	VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
+	Vnm_print(0, "NOsh: Storing y-shifted dielectric map %d path \
+			  %s\n", thee->ndiel, tok);
+	strncpy(thee->dielYpath[thee->ndiel], tok, VMAX_ARGLEN);
+	VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
+	Vnm_print(0, "NOsh: Storing z-shifted dielectric map %d path \
+			  %s\n", thee->ndiel, tok);
+	strncpy(thee->dielZpath[thee->ndiel], tok, VMAX_ARGLEN);
+	thee->dielfmt[thee->ndiel] = dielfmt;
+	(thee->ndiel)++;
+
+	return 1;
 	
 VERROR1:
         Vnm_print(2, "NOsh_parseREAD_DIEL:  Ran out of tokens while parsing READ \
@@ -676,28 +685,32 @@ VPRIVATE int NOsh_parseREAD_KAPPA(NOsh *thee, Vio *sock) {
     VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
     if (Vstring_strcasecmp(tok, "dx") == 0) {
         kappafmt = VDF_DX;
-        VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
-        if (tok[0]=='"') {
-            strcpy(strnew, "");
-            while (tok[strlen(tok)-1] != '"') {
-                strcat(str, tok);
-                strcat(str, " ");
-                VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
-			}
-            strcat(str, tok);
-            strncpy(strnew, str+1, strlen(str)-2);
-            strcpy(tok, strnew);
-        }
-        Vnm_print(0, "NOsh: Storing kappa map %d path %s\n",
-				  thee->nkappa, tok);
-        thee->kappafmt[thee->nkappa] = kappafmt;
-        strncpy(thee->kappapath[thee->nkappa], tok, VMAX_ARGLEN);
-        (thee->nkappa)++;
-    } else {
+	} else if (Vstring_strcasecmp(tok, "gz") == 0) {
+        kappafmt = VDF_GZ;
+	} else {
         Vnm_print(2, "NOsh_parseREAD:  Ignoring undefined format \
-%s!\n", tok);
-    }
+				  %s!\n", tok);
+		return VRC_FAILURE;
+	}
 	
+	VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
+	if (tok[0]=='"') {
+		strcpy(strnew, "");
+		while (tok[strlen(tok)-1] != '"') {
+			strcat(str, tok);
+			strcat(str, " ");
+			VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
+		}
+		strcat(str, tok);
+		strncpy(strnew, str+1, strlen(str)-2);
+		strcpy(tok, strnew);
+	}
+	Vnm_print(0, "NOsh: Storing kappa map %d path %s\n",
+			  thee->nkappa, tok);
+	thee->kappafmt[thee->nkappa] = kappafmt;
+	strncpy(thee->kappapath[thee->nkappa], tok, VMAX_ARGLEN);
+	(thee->nkappa)++;
+    
     return 1;
 	
 VERROR1:
@@ -707,6 +720,49 @@ section!\n");
 	
 }
 
+VPRIVATE int NOsh_parseREAD_POTENTIAL(NOsh *thee, Vio *sock) {
+	
+    char tok[VMAX_BUFSIZE], str[VMAX_BUFSIZE]="", strnew[VMAX_BUFSIZE]="";
+    Vdata_Format potfmt;
+	
+    VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
+    if (Vstring_strcasecmp(tok, "dx") == 0) {
+        potfmt = VDF_DX;
+	} else if (Vstring_strcasecmp(tok, "gz") == 0) {
+        potfmt = VDF_GZ;
+	} else {
+        Vnm_print(2, "NOsh_parseREAD:  Ignoring undefined format \
+				  %s!\n", tok);
+		return VRC_FAILURE;
+   }
+	
+	VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
+	if (tok[0]=='"') {
+		strcpy(strnew, "");
+		while (tok[strlen(tok)-1] != '"') {
+			strcat(str, tok);
+			strcat(str, " ");
+			VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
+		}
+		strcat(str, tok);
+		strncpy(strnew, str+1, strlen(str)-2);
+		strcpy(tok, strnew);
+	}
+	Vnm_print(0, "NOsh: Storing potential map %d path %s\n",
+			  thee->npot, tok);
+	thee->potfmt[thee->npot] = potfmt;
+	strncpy(thee->potpath[thee->npot], tok, VMAX_ARGLEN);
+	(thee->npot)++;
+    
+	return 1;
+	
+VERROR1:
+	Vnm_print(2, "NOsh_parseREAD:  Ran out of tokens while parsing READ \
+			  section!\n");
+	return 0;
+	
+}
+
 VPRIVATE int NOsh_parseREAD_CHARGE(NOsh *thee, Vio *sock) {
 	
     char tok[VMAX_BUFSIZE], str[VMAX_BUFSIZE]="", strnew[VMAX_BUFSIZE]="";
@@ -715,27 +771,31 @@ VPRIVATE int NOsh_parseREAD_CHARGE(NOsh *thee, Vio *sock) {
     VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
     if (Vstring_strcasecmp(tok, "dx") == 0) {
         chargefmt = VDF_DX;
-        VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
-        if (tok[0]=='"') {
-            strcpy(strnew, "");
-            while (tok[strlen(tok)-1] != '"') {
-                strcat(str, tok);
-                strcat(str, " ");
-                VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
-			}
-            strcat(str, tok);
-            strncpy(strnew, str+1, strlen(str)-2);
-            strcpy(tok, strnew);
-        }
-        Vnm_print(0, "NOsh: Storing charge map %d path %s\n",
-				  thee->ncharge, tok);
-        thee->chargefmt[thee->ncharge] = chargefmt;
-        strncpy(thee->chargepath[thee->ncharge], tok, VMAX_ARGLEN);
-        (thee->ncharge)++;
-    } else {
+	} else if (Vstring_strcasecmp(tok, "gz") == 0) {
+        chargefmt = VDF_GZ;
+	} else {
         Vnm_print(2, "NOsh_parseREAD:  Ignoring undefined format \
-%s!\n", tok);
-    }
+				  %s!\n", tok);
+		return VRC_FAILURE;
+	}
+	
+	VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
+	if (tok[0]=='"') {
+		strcpy(strnew, "");
+		while (tok[strlen(tok)-1] != '"') {
+			strcat(str, tok);
+			strcat(str, " ");
+			VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
+		}
+		strcat(str, tok);
+		strncpy(strnew, str+1, strlen(str)-2);
+		strcpy(tok, strnew);
+	}
+	Vnm_print(0, "NOsh: Storing charge map %d path %s\n",
+			  thee->ncharge, tok);
+	thee->chargefmt[thee->ncharge] = chargefmt;
+	strncpy(thee->chargepath[thee->ncharge], tok, VMAX_ARGLEN);
+	(thee->ncharge)++;
 	
     return 1;
 	
@@ -818,6 +878,8 @@ VPRIVATE int NOsh_parseREAD(NOsh *thee, Vio *sock) {
             NOsh_parseREAD_DIEL(thee,sock);
         } else if (Vstring_strcasecmp(tok, "kappa") == 0) {
             NOsh_parseREAD_KAPPA(thee,sock);
+		} else if (Vstring_strcasecmp(tok, "pot") == 0) {
+            NOsh_parseREAD_POTENTIAL(thee,sock);
         } else if (Vstring_strcasecmp(tok, "charge") == 0) {
             NOsh_parseREAD_CHARGE(thee,sock);
 		} else if (Vstring_strcasecmp(tok, "mesh") == 0) {
@@ -828,7 +890,6 @@ VPRIVATE int NOsh_parseREAD(NOsh *thee, Vio *sock) {
         }
     }
 	
-	
     /* We ran out of tokens! */
     Vnm_print(2, "NOsh_parseREAD:  Ran out of tokens while parsing READ \
 section!\n");
@@ -1160,7 +1221,9 @@ VPUBLIC int NOsh_setupElecCalc(
 		/* Unload the calculation object containing the ELEC information */
 		elec = thee->elec[ielec];
 		
-		if (((thee->ndiel != 0) || (thee->nkappa != 0) || (thee->ncharge != 0)) && (elec->pbeparm->calcforce != PCF_NO)) {
+		if (((thee->ndiel != 0) || (thee->nkappa != 0) ||
+			 (thee->ncharge != 0) || (thee->npot != 0)) &&
+				(elec->pbeparm->calcforce != PCF_NO)) {
 			Vnm_print(2, "NOsh_setupElecCalc:  Calculation of forces disabled because surface \
 map is used!\n");
 			elec->pbeparm->calcforce = PCF_NO;
