@@ -3,24 +3,18 @@
  *  @ingroup PBEparm
  *  @author  Nathan Baker
  *  @brief   Class PBEparm methods
- *  @version $Id: pbeparm.c 1389 2009-08-19 17:21:23Z sdg0919 $
+ *  @version $Id: pbeparm.c 1615 2010-10-20 19:16:35Z sobolevnrm $
  *  @attention
  *  @verbatim
  *
  * APBS -- Adaptive Poisson-Boltzmann Solver
  *
- * Nathan A. Baker (baker@biochem.wustl.edu)
- * Dept. of Biochemistry and Molecular Biophysics
- * Center for Computational Biology
- * Washington University in St. Louis
+ * Nathan A. Baker (nathan.baker@pnl.gov)
+ * Pacific Northwest National Laboratory
  *
  * Additional contributing authors listed in the code documentation.
  *
- * Copyright (c) 2002-2009, Washington University in St. Louis.
- * Portions Copyright (c) 2002-2009.  Nathan A. Baker
- * Portions Copyright (c) 1999-2002.  The Regents of the University of California.
- * Portions Copyright (c) 1995.  Michael Holst
- *
+ * Copyright (c) 2010, Pacific Northwest National Laboratory.  Portions Copyright (c) 2002-2010, Washington University in St. Louis.  Portions Copyright (c) 2002-2010, Nathan A. Baker.  Portions Copyright (c) 1999-2002, The Regents of the University of California. Portions Copyright (c) 1995, Michael Holst.
  * All rights reserved.
  * 
  * Redistribution and use in source and binary forms, with or without
@@ -56,7 +50,7 @@
 #include "apbs/pbeparm.h"
 #include "apbs/vstring.h"
 
-VEMBED(rcsid="$Id: pbeparm.c 1389 2009-08-19 17:21:23Z sdg0919 $")
+VEMBED(rcsid="$Id: pbeparm.c 1615 2010-10-20 19:16:35Z sobolevnrm $")
 
 #if !defined(VINLINE_MGPARM)
 
@@ -147,6 +141,7 @@ VPUBLIC int PBEparm_ctor2(PBEparm *thee) {
     thee->srad = 1.4;
     thee->useDielMap = 0;
     thee->useKappaMap = 0;
+	thee->usePotMap = 0;
     thee->useChargeMap = 0;
 	
 	/*----------------------------------------------*/
@@ -292,6 +287,8 @@ VPUBLIC void PBEparm_copy(PBEparm *thee, PBEparm *parm) {
     thee->dielMapID = parm->dielMapID;
     thee->useKappaMap = parm->useKappaMap;
     thee->kappaMapID = parm->kappaMapID;
+	thee->usePotMap = parm->usePotMap;
+	thee->potMapID = parm->potMapID;
     thee->useChargeMap = parm->useChargeMap;
     thee->chargeMapID = parm->chargeMapID;
     thee->pbetype = parm->pbetype; 
@@ -498,6 +495,9 @@ statement\n", ti);
                 break;
 			case BCFL_MEM:
                 Vnm_print(2, "mem");
+                break;
+			case BCFL_MAP:
+                Vnm_print(2, "map");
                 break;
             default:
                 Vnm_print(2, "UKNOWN");
@@ -529,6 +529,10 @@ statement\n", ti);
             thee->bcfl = BCFL_MEM;
             thee->setbcfl = 1;
             return 1;
+        } else if (Vstring_strcasecmp(tok, "map") == 0) {
+            thee->bcfl = BCFL_MAP;
+            thee->setbcfl = 1;
+            return 1;
         } else {
             Vnm_print(2, "NOsh:  parsed unknown BCFL parameter (%s)!\n",
               tok);
@@ -706,7 +710,7 @@ VPRIVATE int PBEparm_parseSRFM(PBEparm *thee, Vio *sock) {
     if (sscanf(tok, "%d", &ti) == 1) {
         thee->srfm = ti;
         thee->setsrfm = 1;
-
+		
         Vnm_print(2, "parsePBE:  Warning -- parsed deprecated \"srfm %d\" \
 statement.\n", ti);
         Vnm_print(2, "parsePBE:  Please use \"srfm ");
@@ -850,6 +854,16 @@ USEMAP KAPPA keyword!\n", tok);
         }
         thee->kappaMapID = ti;
         return 1;
+    } else if (Vstring_strcasecmp(tok, "pot") == 0) {
+        thee->usePotMap = 1;
+        VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
+        if (sscanf(tok, "%d", &ti) == 0) {
+            Vnm_print(2, "NOsh:  Read non-int (%s) while parsing \
+					  USEMAP POT keyword!\n", tok);
+            return -1;
+        }
+        thee->potMapID = ti;
+        return 1;
     } else if (Vstring_strcasecmp(tok, "charge") == 0) {
         thee->useChargeMap = 1;
         VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
@@ -1069,7 +1083,9 @@ VPRIVATE int PBEparm_parseWRITE(PBEparm *thee, Vio *sock) {
     VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
     if (Vstring_strcasecmp(tok, "pot") == 0) {
         writetype = VDT_POT;
-    } else if (Vstring_strcasecmp(tok, "charge") == 0) {
+    } else if (Vstring_strcasecmp(tok, "atompot") == 0) {
+        writetype = VDT_ATOMPOT;
+    }  else if (Vstring_strcasecmp(tok, "charge") == 0) {
         writetype = VDT_CHARGE;
     } else if (Vstring_strcasecmp(tok, "smol") == 0) {
         writetype = VDT_SMOL;
@@ -1107,6 +1123,10 @@ VPRIVATE int PBEparm_parseWRITE(PBEparm *thee, Vio *sock) {
         writefmt = VDF_UHBD;
     } else if (Vstring_strcasecmp(tok, "avs") == 0) {
         writefmt = VDF_AVS;
+    } else if (Vstring_strcasecmp(tok, "gz") == 0) {
+        writefmt = VDF_GZ;
+    } else if (Vstring_strcasecmp(tok, "flat") == 0) {
+        writefmt = VDF_FLAT;
     } else {
         Vnm_print(2, "PBEparm_parse:  Invalid data format (%s) to write!\n",
            tok);
@@ -1180,7 +1200,6 @@ WRITEMAT keyword!\n", tok);
 VPUBLIC int PBEparm_parseToken(PBEparm *thee, char tok[VMAX_BUFSIZE], 
   Vio *sock) {
 
-
     if (thee == VNULL) {
         Vnm_print(2, "parsePBE:  got NULL thee!\n");
         return -1;
