@@ -3,24 +3,18 @@
  *  @ingroup Vacc
  *  @author  Nathan Baker
  *  @brief   Class Vacc methods
- *  @version $Id: vacc.c 1367 2009-04-24 17:11:03Z sdg0919 $
+ *  @version $Id: vacc.c 1615 2010-10-20 19:16:35Z sobolevnrm $
  *  @attention
  *  @verbatim
  *
  * APBS -- Adaptive Poisson-Boltzmann Solver
  *
- * Nathan A. Baker (baker@biochem.wustl.edu)
- * Dept. of Biochemistry and Molecular Biophysics
- * Center for Computational Biology
- * Washington University in St. Louis
+ * Nathan A. Baker (nathan.baker@pnl.gov)
+ * Pacific Northwest National Laboratory
  *
  * Additional contributing authors listed in the code documentation.
  *
- * Copyright (c) 2002-2009, Washington University in St. Louis.
- * Portions Copyright (c) 2002-2009.  Nathan A. Baker
- * Portions Copyright (c) 1999-2002.  The Regents of the University of California.
- * Portions Copyright (c) 1995.  Michael Holst
- *
+ * Copyright (c) 2010, Pacific Northwest National Laboratory.  Portions Copyright (c) 2002-2010, Washington University in St. Louis.  Portions Copyright (c) 2002-2010, Nathan A. Baker.  Portions Copyright (c) 1999-2002, The Regents of the University of California. Portions Copyright (c) 1995, Michael Holst.
  * All rights reserved.
  * 
  * Redistribution and use in source and binary forms, with or without
@@ -60,7 +54,7 @@
 #include "mc/mc.h"
 #endif
 
-VEMBED(rcsid="$Id: vacc.c 1367 2009-04-24 17:11:03Z sdg0919 $")
+VEMBED(rcsid="$Id: vacc.c 1615 2010-10-20 19:16:35Z sobolevnrm $")
 
 #if !defined(VINLINE_VACC)
 
@@ -658,14 +652,20 @@ VPUBLIC double Vacc_SASA(Vacc *thee, double radius) {
     double area, *apos;
     Vatom *atom;
     VaccSurf *asurf;
+
+	unsigned long long mbeg;
 	
     natom = Valist_getNumberAtoms(thee->alist);
-	
+
     /* Check to see if we need to build the surface */
     if (thee->surf == VNULL) {
         thee->surf = Vmem_malloc(thee->mem, natom, sizeof(VaccSurf *));
-		
-//#pragma omp parallel for private(i,atom)
+
+#if defined(DEBUG_MAC_OSX_OCL) || defined(DEBUG_MAC_OSX_STANDARD)
+#include "mach_chud.h"
+		machm_(&mbeg);
+#pragma omp parallel for private(i,atom)
+#endif
         for (i=0; i<natom; i++) {
             atom = Valist_getAtom(thee->alist, i);
             /* NOTE:  RIGHT NOW WE DO THIS FOR THE ENTIRE MOLECULE WHICH IS
@@ -691,6 +691,10 @@ VPUBLIC double Vacc_SASA(Vacc *thee, double radius) {
         area += (asurf->area);
     }
 	
+#if defined(DEBUG_MAC_OSX_OCL) || defined(DEBUG_MAC_OSX_STANDARD)
+	mets_(&mbeg, "Vacc_SASA - Parallel");
+#endif
+	
     return area;
 	
 }
@@ -728,6 +732,11 @@ VPUBLIC VaccSurf* VaccSurf_ctor(Vmem *mem, double probe_radius, int nsphere) {
     VaccSurf *thee;
 
     //thee = Vmem_malloc(mem, 1, sizeof(Vacc) );
+	if (nsphere >= MAX_SPHERE_PTS) {
+		Vnm_print(2, "VaccSurf_ctor:  Error!  The requested number of grid points (%d) exceeds the maximum (%d)!\n", nsphere, MAX_SPHERE_PTS);
+		Vnm_print(2, "VaccSurf_ctor:  Please check the variable MAX_SPHERE_PTS to reset.\n");
+		VASSERT(0);
+	}
 	thee = (VaccSurf*)calloc(1,sizeof(Vacc));
     VASSERT( VaccSurf_ctor2(thee, mem, probe_radius, nsphere) );
 
@@ -805,7 +814,7 @@ VPUBLIC VaccSurf* Vacc_atomSurf(Vacc *thee, Vatom *atom,
     VaccSurf *surf;
     int i, j, npts, atomID;
     double arad, rad, pos[3], *apos;
-	char bpts[ref->npts];
+	char bpts[MAX_SPHERE_PTS];
 			  
     /* Get atom information */
     arad = Vatom_getRadius(atom);
@@ -1288,6 +1297,9 @@ VPUBLIC void Vacc_atomdSASA(Vacc *thee, double dpos, double srad, Vatom *atom, d
     temp_Pos[2] += dpos; 
     azt1 = Vacc_atomSASAPos(thee, srad, atom,0);
 	temp_Pos[2] = tPos[2];
+	
+	/* Reset the atom SASA to zero displacement */
+	Vacc_atomSASAPos(thee, srad, atom,0);
     
 	/* Calculate the final value */
     dSA[0] = (axt1-axb1)/(2.0 * dpos);
