@@ -2,24 +2,18 @@
  *  @file    valist.c
  *  @author  Nathan Baker
  *  @brief   Class Valist methods
- *  @version $Id: valist.c 1393 2009-08-26 16:00:23Z yhuang01 $
+ *  @version $Id: valist.c 1615 2010-10-20 19:16:35Z sobolevnrm $
  *  @attention
  *  @verbatim
  *
  * APBS -- Adaptive Poisson-Boltzmann Solver
  *
- * Nathan A. Baker (baker@biochem.wustl.edu)
- * Dept. of Biochemistry and Molecular Biophysics
- * Center for Computational Biology
- * Washington University in St. Louis
+ * Nathan A. Baker (nathan.baker@pnl.gov)
+ * Pacific Northwest National Laboratory
  *
  * Additional contributing authors listed in the code documentation.
  *
- * Copyright (c) 2002-2009, Washington University in St. Louis.
- * Portions Copyright (c) 2002-2009.  Nathan A. Baker
- * Portions Copyright (c) 1999-2002.  The Regents of the University of California.
- * Portions Copyright (c) 1995.  Michael Holst
- *
+ * Copyright (c) 2010, Pacific Northwest National Laboratory.  Portions Copyright (c) 2002-2010, Washington University in St. Louis.  Portions Copyright (c) 2002-2010, Nathan A. Baker.  Portions Copyright (c) 1999-2002, The Regents of the University of California. Portions Copyright (c) 1995, Michael Holst.
  * All rights reserved.
  * 
  * Redistribution and use in source and binary forms, with or without
@@ -54,7 +48,7 @@
 #include "apbscfg.h"
 #include "apbs/valist.h"
 
-VEMBED(rcsid="$Id: valist.c 1393 2009-08-26 16:00:23Z yhuang01 $")
+VEMBED(rcsid="$Id: valist.c 1615 2010-10-20 19:16:35Z sobolevnrm $")
 
 VPRIVATE char *Valist_whiteChars = " \t\r\n";
 VPRIVATE char *Valist_commChars  = "#%";
@@ -621,6 +615,8 @@ VPUBLIC Vrc_Codes Valist_readPQR(Valist *thee, Vparam *params, Vio *sock) {
     double x, y, z, charge, radius, epsilon;
     double pos[3];
  
+	epsilon = 0.0;
+
     if (thee == VNULL) {
 		Vnm_print(2, "Valist_readPQR:  Got NULL pointer when reading PQR file!\n");
 		VASSERT(0);
