@@ -3,24 +3,18 @@
  *  @author  Nathan Baker
  *  @brief   Class Vgrid methods
  *  @ingroup Vgrid
- *  @version $Id: vgrid.c 1377 2009-06-15 20:26:27Z yhuang01 $
+ *  @version $Id: vgrid.c 1615 2010-10-20 19:16:35Z sobolevnrm $
  *  @attention
  *  @verbatim 
  *
  * APBS -- Adaptive Poisson-Boltzmann Solver
  *
- * Nathan A. Baker (baker@biochem.wustl.edu)
- * Dept. of Biochemistry and Molecular Biophysics
- * Center for Computational Biology
- * Washington University in St. Louis
+ * Nathan A. Baker (nathan.baker@pnl.gov)
+ * Pacific Northwest National Laboratory
  *
  * Additional contributing authors listed in the code documentation.
  *
- * Copyright (c) 2002-2009, Washington University in St. Louis.
- * Portions Copyright (c) 2002-2009.  Nathan A. Baker
- * Portions Copyright (c) 1999-2002.  The Regents of the University of California.
- * Portions Copyright (c) 1995.  Michael Holst
- *
+ * Copyright (c) 2010, Pacific Northwest National Laboratory.  Portions Copyright (c) 2002-2010, Washington University in St. Louis.  Portions Copyright (c) 2002-2010, Nathan A. Baker.  Portions Copyright (c) 1999-2002, The Regents of the University of California. Portions Copyright (c) 1995, Michael Holst.
  * All rights reserved.
  * 
  * Redistribution and use in source and binary forms, with or without
@@ -55,7 +49,7 @@
 #include "apbscfg.h"
 #include "apbs/vgrid.h"
 
-VEMBED(rcsid="$Id: vgrid.c 1377 2009-06-15 20:26:27Z yhuang01 $")
+VEMBED(rcsid="$Id: vgrid.c 1615 2010-10-20 19:16:35Z sobolevnrm $")
 
 #if !defined(VINLINE_VGRID)
     VPUBLIC unsigned long int Vgrid_memChk(Vgrid *thee) { 
@@ -431,6 +425,128 @@ VPUBLIC int Vgrid_gradient(Vgrid *thee, double pt[3], double grad[3]) {
 
 }
 
+/* ///////////////////////////////////////////////////////////////////////////
+ // Routine:  Vgrid_readGZ
+ //
+ // Author:   David Gohara
+ /////////////////////////////////////////////////////////////////////////// */
+#ifdef HAVE_ZLIB
+#define off_t long
+#include "../../contrib/zlib/zlib.h"
+#endif
+VPUBLIC int Vgrid_readGZ(Vgrid *thee, const char *fname) {
+
+#ifdef HAVE_ZLIB
+	int i, j, k, q, itmp, u, header;
+	int length, incr;
+	double * temp;
+	double dtmp1, dtmp2, dtmp3;
+	gzFile infile;
+	char line[VMAX_ARGLEN];
+
+	header = 0;
+	
+	/* Check to see if the existing data is null and, if not, clear it out */
+    if (thee->data != VNULL) {
+        Vnm_print(1, "Vgrid_readDX:  destroying existing data!\n");
+		Vmem_free(thee->mem, (thee->nx*thee->ny*thee->nz), sizeof(double),
+				  (void **)&(thee->data)); }
+    thee->readdata = 1;
+    thee->ctordata = 0;
+	
+	infile = gzopen(fname, "rb");
+	if (infile == Z_NULL) {
+        Vnm_print(2, "Vgrid_writeDX:  Problem opening compressed file %s\n",
+				  fname);
+        return VRC_FAILURE;
+    }
+	
+	thee->hx = 0.0;
+	thee->hy = 0.0;
+	thee->hzed = 0.0;
+	
+	//read data here
+	while (header < 7) {
+		if(gzgets(infile, line, VMAX_ARGLEN) == Z_NULL){
+			return VRC_FAILURE;
+		}
+		if(strncmp(line, "#", 1) == 0) continue;
+		if(line[0] == '\n') continue; 
+		
+		switch (header) {
+			case 0:
+				sscanf(line, "object 1 class gridpositions counts %d %d %d",
+					   &(thee->nx),&(thee->ny),&(thee->nz));
+				break;
+			case 1:
+				sscanf(line, "origin %lf %lf %lf",
+					   &(thee->xmin),&(thee->ymin),&(thee->zmin));
+				break;
+			case 2:
+			case 3:
+			case 4:
+				sscanf(line, "delta %lf %lf %lf",&dtmp1,&dtmp2,&dtmp3);
+				thee->hx += dtmp1;
+				thee->hy += dtmp2;
+				thee->hzed += dtmp3;
+				break;
+			default:
+				break;
+		}
+		
+		header++;
+	}
+	
+	/* Allocate space for the data */
+    Vnm_print(0, "Vgrid_readGZ:  allocating %d x %d x %d doubles for storage\n",
+			  thee->nx, thee->ny, thee->nz);
+    thee->data = VNULL;
+    thee->data = Vmem_malloc(thee->mem, (thee->nx)*(thee->ny)*(thee->nz), 
+							 sizeof(double));
+    if (thee->data == VNULL) {
+        Vnm_print(2, "Vgrid_readGZ:  Unable to allocate space for data!\n");
+        return 0;
+    }
+	
+	/* Allocate a temporary buffer to store the compressed 
+	 * data into (column major order). Add 2 to ensure the buffer is
+	 * big enough to take extra data on the final read loop.
+	 */
+	temp = (double *)malloc(thee->nx*thee->ny*thee->nz*sizeof(double) + 2);
+	for(i=0;i<thee->nx*thee->ny*thee->nz;i+=3){
+		gzgets(infile, line, length);
+		sscanf(line, "%lf %lf %lf",&temp[i],&temp[i+1],&temp[i+2]);
+	}
+	
+	/* Now move the data to row major order */
+	incr = 0;
+	for (i=0; i<thee->nx; i++) {
+		for (j=0; j<thee->ny; j++) {
+			for (k=0; k<thee->nz; k++) {
+				u = k*(thee->nx)*(thee->ny)+j*(thee->nx)+i;
+				(thee->data)[u] = temp[incr++];
+			}
+		}
+	}
+	
+	/* calculate grid maxima */
+	thee->xmax = thee->xmin + (thee->nx-1)*thee->hx;
+	thee->ymax = thee->ymin + (thee->ny-1)*thee->hy;
+	thee->zmax = thee->zmin + (thee->nz-1)*thee->hzed;
+	
+	/* Close off the socket */
+	gzclose(infile);
+	free(temp);
+#else
+	
+	Vnm_print(0, "WARNING\n");
+	Vnm_print(0, "Vgrid_readGZ:  gzip read/write support is disabled in this build\n");
+	Vnm_print(0, "Vgrid_readGZ:  configure and compile without the --disable-zlib flag.\n");
+	Vnm_print(0, "WARNING\n");
+#endif	
+	return VRC_SUCCESS;
+} 
+
 /* ///////////////////////////////////////////////////////////////////////////
 // Routine:  Vgrid_readDX
 //
@@ -653,6 +769,200 @@ VPUBLIC int Vgrid_readDX(Vgrid *thee, const char *iodev, const char *iofmt,
 
 
 
+}
+
+/* ///////////////////////////////////////////////////////////////////////////
+ // Routine:  Vgrid_writeGZ
+ //
+ // Author:   Nathan Baker
+ /////////////////////////////////////////////////////////////////////////// */
+VPUBLIC void Vgrid_writeGZ(Vgrid *thee, const char *iodev, const char *iofmt,
+							const char *thost, const char *fname, char *title, double *pvec) {
+	
+#ifdef HAVE_ZLIB
+	double xmin, ymin, zmin, hx, hy, hzed;
+	
+	int nx, ny, nz;
+	int icol, i, j, k, u, usepart, nxPART, nyPART, nzPART, gotit;
+	double x, y, z, xminPART, yminPART, zminPART;
+	
+	int txyz;
+	double txmin, tymin, tzmin;
+	
+	char header[8196];
+	char footer[8196];
+	char line[80];
+	char newline[] = "\n";
+	gzFile outfile;
+	char precFormat[VMAX_BUFSIZE];
+	
+	if (thee == VNULL) {
+		Vnm_print(2, "Vgrid_writeGZ:  Error -- got VNULL thee!\n");
+		VASSERT(0);
+	}
+	if (!(thee->ctordata || thee->readdata)) {
+		Vnm_print(2, "Vgrid_writeGZ:  Error -- no data available!\n");
+		VASSERT(0);
+	}
+	
+	hx = thee->hx;
+	hy = thee->hy; 
+	hzed = thee->hzed; 
+	nx = thee->nx;
+	ny = thee->ny;
+	nz = thee->nz;
+	xmin = thee->xmin;
+	ymin = thee->ymin;
+	zmin = thee->zmin;
+	
+	if (pvec == VNULL) usepart = 0;
+	else usepart = 1;
+	
+	/* Set up the virtual socket */
+	Vnm_print(0, "Vgrid_writeGZ:  Opening file...\n");
+	outfile = gzopen(fname, "wb");
+	
+	if (usepart) {
+		/* Get the lower corner and number of grid points for the local
+		 * partition */
+		xminPART = VLARGE;
+		yminPART = VLARGE;
+		zminPART = VLARGE;
+		nxPART = 0;
+		nyPART = 0;
+		nzPART = 0;
+		/* First, search for the lower corner */
+		for (k=0; k<nz; k++) {
+			z = k*hzed + zmin;
+			for (j=0; j<ny; j++) {
+				y = j*hy + ymin;
+				for (i=0; i<nx; i++) {
+					x = i*hx + xmin;
+					if (pvec[IJK(i,j,k)] > 0.0) {
+						if (x < xminPART) xminPART = x;
+						if (y < yminPART) yminPART = y;
+						if (z < zminPART) zminPART = z;
+					}
+				}
+			}
+		}
+		/* Now search for the number of grid points in the z direction */
+		for (k=0; k<nz; k++) {
+			gotit = 0;
+			for (j=0; j<ny; j++) {
+				for (i=0; i<nx; i++) {
+					if (pvec[IJK(i,j,k)] > 0.0) {
+						gotit = 1;
+						break;
+					}
+				}
+				if (gotit) break;
+			}
+			if (gotit) nzPART++;
+		}
+		/* Now search for the number of grid points in the y direction */
+		for (j=0; j<ny; j++) {
+			gotit = 0;
+			for (k=0; k<nz; k++) {
+				for (i=0; i<nx; i++) {
+					if (pvec[IJK(i,j,k)] > 0.0) {
+						gotit = 1;
+						break;
+					}
+				}
+				if (gotit) break;
+			}
+			if (gotit) nyPART++;
+		}
+		/* Now search for the number of grid points in the x direction */
+		for (i=0; i<nx; i++) {
+			gotit = 0;
+			for (k=0; k<nz; k++) {
+				for (j=0; j<ny; j++) {
+					if (pvec[IJK(i,j,k)] > 0.0) {
+						gotit = 1;
+						break; 
+					}
+				}
+				if (gotit) break;
+			}
+			if (gotit) nxPART++;
+		}
+		
+		if ((nxPART != nx) || (nyPART != ny) || (nzPART != nz)) {
+			Vnm_print(0, "Vgrid_writeGZ:  printing only subset of domain\n");
+		}
+		
+		txyz = (nxPART*nyPART*nzPART);
+		txmin = xminPART;
+		tymin = yminPART;
+		tzmin = zminPART;
+		
+	}else {
+		
+		txyz = (nx*ny*nz);
+		txmin = xmin;
+		tymin = ymin;
+		tzmin = zmin;
+		
+	}
+	
+	/* Write off the title (if we're not XDR) */
+	sprintf(header,
+			"# Data from %s\n"	\
+			"# \n"							\
+			"# %s\n"			\
+			"# \n"							\
+			"object 1 class gridpositions counts %i %i %i\n"	\
+			"origin %12.6e %12.6e %12.6e\n"	\
+			"delta %12.6e 0.000000e+00 0.000000e+00\n"		\
+			"delta 0.000000e+00 %12.6e 0.000000e+00\n"		\
+			"delta 0.000000e+00 0.000000e+00 %12.6e\n"		\
+			"object 2 class gridconnections counts %i %i %i\n"\
+			"object 3 class array type double rank 0 items %i data follows\n",
+			PACKAGE_STRING,title,nx,ny,nz,txmin,tymin,tzmin,
+			hx,hy,hzed,nx,ny,nz,txyz);
+	gzwrite(outfile, header, strlen(header)*sizeof(char));
+	
+	/* Now write the data */
+	icol = 0;
+	for (i=0; i<nx; i++) {
+		for (j=0; j<ny; j++) {
+			for (k=0; k<nz; k++) {
+				u = k*(nx)*(ny)+j*(nx)+i;
+				if (pvec[u] > 0.0) {
+					sprintf(line, "%12.6e ", thee->data[u]);
+					gzwrite(outfile, line, strlen(line)*sizeof(char));
+					icol++;
+					if (icol == 3) {
+						icol = 0;
+						gzwrite(outfile, newline, strlen(newline)*sizeof(char));
+					}
+				}
+			}
+		}
+	}
+	if(icol < 3){
+		char newline[] = "\n";
+		gzwrite(outfile, newline, strlen(newline)*sizeof(char));
+	}
+	
+	/* Create the field */
+	sprintf(footer, "attribute \"dep\" string \"positions\"\n" \
+			"object \"regular positions regular connections\" class field\n" \
+			"component \"positions\" value 1\n" \
+			"component \"connections\" value 2\n" \
+			"component \"data\" value 3\n");
+	gzwrite(outfile, footer, strlen(footer)*sizeof(char));
+	
+	gzclose(outfile);
+#else
+	
+	Vnm_print(0, "WARNING\n");
+	Vnm_print(0, "Vgrid_readGZ:  gzip read/write support is disabled in this build\n");
+	Vnm_print(0, "Vgrid_readGZ:  configure and compile without the --disable-zlib flag.\n");
+	Vnm_print(0, "WARNING\n");
+#endif	
 }
 
 /* ///////////////////////////////////////////////////////////////////////////
