@@ -3,24 +3,18 @@
  *  @author  Nathan Baker
  *  @brief   Class Vpmgp methods
  *  @ingroup Vpmgp
- *  @version $Id: vpmgp.c 1365 2009-04-22 18:29:10Z sdg0919 $
+ *  @version $Id: vpmgp.c 1615 2010-10-20 19:16:35Z sobolevnrm $
  *  @attention
  *  @verbatim
  *
  * APBS -- Adaptive Poisson-Boltzmann Solver
  *
- * Nathan A. Baker (baker@biochem.wustl.edu)
- * Dept. of Biochemistry and Molecular Biophysics
- * Center for Computational Biology
- * Washington University in St. Louis
+ * Nathan A. Baker (nathan.baker@pnl.gov)
+ * Pacific Northwest National Laboratory
  *
  * Additional contributing authors listed in the code documentation.
  *
- * Copyright (c) 2002-2009, Washington University in St. Louis.
- * Portions Copyright (c) 2002-2009.  Nathan A. Baker
- * Portions Copyright (c) 1999-2002.  The Regents of the University of California.
- * Portions Copyright (c) 1995.  Michael Holst
- *
+ * Copyright (c) 2010, Pacific Northwest National Laboratory.  Portions Copyright (c) 2002-2010, Washington University in St. Louis.  Portions Copyright (c) 2002-2010, Nathan A. Baker.  Portions Copyright (c) 1999-2002, The Regents of the University of California. Portions Copyright (c) 1995, Michael Holst.
  * All rights reserved.
  * 
  * Redistribution and use in source and binary forms, with or without
@@ -56,7 +50,7 @@
 #include "apbs/vpmgp.h"
 #include "apbs/mgparm.h"
 
-VEMBED(rcsid="$Id: vpmgp.c 1365 2009-04-22 18:29:10Z sdg0919 $")
+VEMBED(rcsid="$Id: vpmgp.c 1615 2010-10-20 19:16:35Z sobolevnrm $")
 
 /* ///////////////////////////////////////////////////////////////////////////
 // Class Vpmgp: Inlineable methods
@@ -107,20 +101,30 @@ VPUBLIC int Vpmgp_ctor2(Vpmgp *thee,MGparm *mgparm) {
     thee->nonlin = mgparm->nonlintype;
 	thee->meth = mgparm->method;
 	
+#ifdef DEBUG_MAC_OSX_OCL
+#include "mach_chud.h"
+	if(kOpenCLAvailable)
+		thee->meth = 4;
+#endif
+	
     if (thee->nonlin == NONLIN_LPBE) thee->ipkey = IPKEY_LPBE; /* LPBE case */
 	else if(thee->nonlin == NONLIN_SMPBE) thee->ipkey = IPKEY_SMPBE; /* SMPBE case */
     else thee->ipkey = IPKEY_NPBE; /* NPBE standard case */
 	
     /* Default parameters */
-    thee->errtol = 1.0e-6;   /* Here are a few comments.  Mike had this set to
+    if (mgparm->setetol) { /* If etol is set by the user in APBS input file, then use this custom-defined etol */
+        thee->errtol = mgparm->etol; 
+        Vnm_print(1, "  Error tolerance (etol) is now set to user-defined \
+value: %g \n", thee->errtol);
+        Vnm_print(0, "Error tolerance (etol) is now set to user-defined \
+value: %g \n", thee->errtol);
+    } else thee->errtol = 1.0e-6;   /* Here are a few comments.  Mike had this set to
 		* 1e-9; convential wisdom sets this at 1e-6 for
 		* the PBE; Ray Luo sets this at 1e-3 for his
 		* accelerated PBE (for dynamics, etc.) */
     thee->itmax = 200;
     thee->istop = 1;
-    thee->iinfo = 1;         /* I'd recommend either 1 (for debugging LPBE) or 
-		* 2 (for debugging NPBE), higher values give 
-		* too much output */
+    thee->iinfo = 1;         /* I'd recommend either 1 (for debugging LPBE) or 2 (for debugging NPBE), higher values give too much output */
 	
     thee->bcfl = BCFL_SDH;
     thee->key = 0;
@@ -145,7 +149,7 @@ VPUBLIC int Vpmgp_ctor2(Vpmgp *thee,MGparm *mgparm) {
 		/* SMPBE Added - SMPBE needs to mimic NPBE */
 		Vnm_print(0, "Vpmp_ctor2:  Using meth = 1, mgsolv = 0\n");
         thee->mgsolv = 0;
-	}else{        
+	} else {        
 		/* Most rigorous (good for testing) */
 		Vnm_print(0, "Vpmp_ctor2:  Using meth = 2, mgsolv = 1\n");
         thee->mgsolv = 1;
@@ -181,3 +185,144 @@ VPUBLIC void Vpmgp_dtor(Vpmgp **thee) {
 // Author:   Nathan Baker
 /////////////////////////////////////////////////////////////////////////// */
 VPUBLIC void Vpmgp_dtor2(Vpmgp *thee) { ; }
+
+
+VPUBLIC void Vpmgp_size(
+	Vpmgp *thee
+	)
+{
+
+	int num_nf = 0;
+	int num_narr = 2;
+	int num_narrc = 27;
+	int nxf, nyf, nzf, level, num_nf_oper, num_narrc_oper, n_band, nc_band, num_band, iretot;
+
+	thee->nf = thee->nx * thee->ny * thee->nz;
+	thee->narr = thee->nf;
+	nxf = thee->nx;
+	nyf = thee->ny;
+	nzf = thee->nz;
+	thee->nxc = thee->nx;
+	thee->nyc = thee->ny;
+	thee->nzc = thee->nz;
+
+	for (level=2; level<=thee->nlev; level++) {
+		Vpmgp_makeCoarse(1, nxf, nyf, nzf, &(thee->nxc), &(thee->nyc), &(thee->nzc)); /* NAB TO-DO -- implement this function and check which variables need to be passed by reference... */
+		nxf = thee->nxc;
+		nyf = thee->nyc;
+		nzf = thee->nzc;
+		thee->narr = thee->narr + (nxf * nyf * nzf);
+	}
+
+	thee->nc = thee->nxc * thee->nyc * thee->nzc;
+	thee->narrc = thee->narr - thee->nf;
+
+	/* Box or FEM discretization on fine grid? */
+	switch (thee->mgdisc) { /* NAB TO-DO:  This needs to be changed into an enumeration */
+	case 0:
+		num_nf_oper = 4;
+		break;
+	case 1:
+		num_nf_oper = 14;
+		break;
+	default:
+		Vnm_print(2, "Vpmgp_size:  Invalid mgdisc value (%d)!\n", thee->mgdisc);
+		VASSERT(0);
+	}
+
+	/* Galerkin or standard coarsening? */
+	switch (thee->mgcoar) { /* NAB TO-DO:  This needs to be changed into an enumeration */
+	case 0:
+		if (thee->mgdisc != 0) {
+			Vnm_print(2, "Vpmgp_size:  Invalid mgcoar value (%d); must be used with mgdisc 0!\n", thee->mgcoar);
+			VASSERT(0);
+		}
+		num_narrc_oper = 4;
+		break;
+	case 1:
+		if (thee->mgdisc != 0) {
+			Vnm_print(2, "Vpmgp_size:  Invalid mgcoar value (%d); must be used with mgdisc 0!\n", thee->mgcoar);
+			VASSERT(0);
+		}
+		num_narrc_oper = 14;
+		break;
+	case 2:
+		num_narrc_oper = 14;
+		break;
+	default:
+		Vnm_print(2, "Vpmgp_size:  Invalid mgcoar value (%d)!\n", thee->mgcoar);
+		VASSERT(0);
+	}
+
+	/* LINPACK storage on coarse grid */
+	switch (thee->mgsolv) { /* NAB TO-DO:  This needs to be changed into an enumeration */
+	case 0:
+		n_band = 0;
+		break;
+	case 1:
+		if ( ( (thee->mgcoar == 0) || (thee->mgcoar == 1)) && (thee->mgdisc == 0) ) {
+			num_band = 1 + (thee->nxc-2)*(thee->nyc-2);
+		} else {
+			num_band = 1 + (thee->nxc-2)*(thee->nyc-2) + (thee->nxc-2) + 1;
+		}
+		nc_band = (thee->nxc-2)*(thee->nyc-2)*(thee->nzc-2);
+		n_band  = nc_band * num_band;
+		break;
+	default:
+		Vnm_print(2, "Vpmgp_size:  Invalid mgsolv value (%d)!\n", thee->mgsolv);
+		VASSERT(0);
+	}
+	
+	/* Real storage parameters */
+	thee->n_rpc = 100*(thee->nlev+1);
+
+	/* Resulting total required for real storage */
+	thee->nrwk = num_narr*thee->narr + (num_nf + num_nf_oper)*thee->nf + (num_narrc + num_narrc_oper)*thee->narrc + n_band + thee->n_rpc;
+
+	/* Integer storage parameters */
+	thee->n_iz = 50*(thee->nlev+1);
+	thee->n_ipc = 100*(thee->nlev+1);
+	thee->niwk = thee->n_iz + thee->n_ipc;
+}
+
+VPRIVATE int coarsenThis(nOld) {
+
+	int nOut;
+
+	nOut = (nOld - 1) / 2 + 1;
+
+	if (((nOut-1)*2) != (nOld-1)) {
+		Vnm_print(2, "Vpmgp_makeCoarse:  Warning!  The grid dimensions you have chosen are not consistent with the nlev you have specified!\n");
+		Vnm_print(2, "Vpmgp_makeCoarse:  This calculation will only work if you are running with mg-dummy type.\n");
+	}
+	if (nOut < 1) {
+		Vnm_print(2, "D'oh!  You coarsened the grid below zero!  How did you do that?\n");
+		VASSERT(0);
+	}
+
+	return nOut;
+}
+
+VPUBLIC void Vpmgp_makeCoarse(
+	int numLevel,
+	int nxOld,
+	int nyOld,
+	int nzOld,
+	int *nxNew,
+	int *nyNew,
+	int *nzNew
+	)
+{
+	int nxtmp, nytmp, nztmp, iLevel;
+
+	for (iLevel=0; iLevel<numLevel; iLevel++) {
+		nxtmp = *nxNew;
+		nytmp = *nyNew;
+		nztmp = *nzNew;
+		*nxNew = coarsenThis(nxtmp);
+		*nyNew = coarsenThis(nytmp);
+		*nzNew = coarsenThis(nztmp);
+	}
+
+
+}
\ No newline at end of file
