@@ -9,49 +9,8 @@ Additional APBS-specific features added by Nathan Baker
 Ported to Python/Psize class by Todd Dolinsky and subsequently hacked by
 Nathan Baker
 
-Version:  $Id: psize.py 1375 2009-06-08 16:26:49Z yhuang01 $
+Version:  $Id: psize.py 1615 2010-10-20 19:16:35Z sobolevnrm $
 
-APBS -- Adaptive Poisson-Boltzmann Solver
-
-  Nathan A. Baker (baker@biochem.wustl.edu)
-  Dept. Biochemistry and Molecular Biophysics
-  Center for Computational Biology
-  Washington University in St. Louis
-
-  Additional contributing authors listed in the code documentation.
-
-Copyright (c) 2002-2009, Washington University in St. Louis.
-Portions Copyright (c) 2002-2009.  Nathan A. Baker
-Portions Copyright (c) 1999-2002.  The Regents of the University of California.
-Portions Copyright (c) 1995.  Michael Holst
-
-All rights reserved.
-
-Redistribution and use in source and binary forms, with or without
-modification, are permitted provided that the following conditions are met: 
-
-* Redistributions of source code must retain the above copyright notice, this
-list of conditions and the following disclaimer.  
-
-* Redistributions in binary form must reproduce the above copyright notice,
-this list of conditions and the following disclaimer in the documentation
-and/or other materials provided with the distribution.
-
-* Neither the name of Washington University in St. Louis nor the names of its
-contributors may be used to endorse or promote products derived from this
-software without specific prior written permission.
-
-THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
-A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
-CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
-EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
-PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
-PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
-LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
-NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
-SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 """
 
@@ -63,8 +22,8 @@ class Psize:
 	"""Master class for parsing input files and suggesting settings"""
 	def __init__(self):
 		self.constants = {"cfac": 1.7, "fadd":20, "space": 0.50, "gmemfac": 200, "gmemceil": 400, "ofrac":0.1, "redfac": 0.25 }
-		self.minlen = [360.0, 360.0, 360.0]
-		self.maxlen = [0.0, 0.0, 0.0]
+		self.minlen = [None, None, None]
+		self.maxlen = [None, None, None]
 		self.q = 0.0
 		self.gotatom = 0
 		self.gothet = 0
@@ -102,8 +61,10 @@ class Psize:
 				for word in words[0:3]:
 					center.append(float(word))
 				for i in range(3):
-					self.minlen[i] = min(center[i]-rad, self.minlen[i])
-					self.maxlen[i] = max(center[i]+rad, self.maxlen[i])
+					if self.minlen[i] == None or center[i]-rad < self.minlen[i]:
+						self.minlen[i] = center[i]-rad
+					if self.maxlen[i] == None or center[i]+rad > self.maxlen[i]:
+						self.maxlen[i] = center[i]+rad
 			elif string.find(line, "HETATM") == 0:
 				self.gothet = self.gothet + 1
 				# Special handling for no ATOM entries in the pqr file, only HETATM entries
@@ -118,8 +79,10 @@ class Psize:
 					for word in words[0:3]:
 						center.append(float(word))
 					for i in range(3):
-						self.minlen[i] = min(center[i]-rad, self.minlen[i])
-						self.maxlen[i] = max(center[i]+rad, self.maxlen[i])
+						if self.minlen[i] == None or center[i]-rad < self.minlen[i]:
+							self.minlen[i] = center[i]-rad
+						if self.maxlen[i] == None or center[i]+rad > self.maxlen[i]:
+							self.maxlen[i] = center[i]+rad
 
 	def setConstant(self, name, value):
 		""" Set a constant to a value; returns 0 if constant not found """
