@@ -2,64 +2,16 @@
 *  @file     mergedx2.c
  *  @author  David Gohara, Stephen Bond and Nathan Baker
  *  @brief   Program that merges OpenDX files
- *  @version $Id: mergedx2.c 1350 2009-02-12 00:38:48Z yhuang01 $
- *
- *  @attention
- *  @verbatim
- *
- * APBS -- Adaptive Poisson-Boltzmann Solver
- *
- * Nathan A. Baker (baker@biochem.wustl.edu)
- * Dept. of Biochemistry and Molecular Biophysics
- * Center for Computational Biology
- * Washington University in St. Louis
- *
- * Additional contributing authors listed in the code documentation.
- *
- * Copyright (c) 2002-2009, Washington University in St. Louis.
- * Portions Copyright (c) 2002-2009.  Nathan A. Baker
- * Portions Copyright (c) 1999-2002.  The Regents of the University of California.
- * Portions Copyright (c) 1995.  Michael Holst
- *
- * All rights reserved.
- * 
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions are met: 
- *
- * -  Redistributions of source code must retain the above copyright notice, this
- * list of conditions and the following disclaimer.  
- * 
- * - Redistributions in binary form must reproduce the above copyright notice,
- * this list of conditions and the following disclaimer in the documentation
- * and/or other materials provided with the distribution.
- * 
- * - Neither the name of Washington University in St. Louis nor the names of its
- * contributors may be used to endorse or promote products derived from this
- * software without specific prior written permission.
- * 
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
- * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
- * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
- * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
- * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
- * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
- * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
- * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. *
- * @endverbatim
+ *  @version $Id: mergedx2.c 1615 2010-10-20 19:16:35Z sobolevnrm $
  */
 
-#include <unistd.h>
-
 #include "apbscfg.h"
 #include "apbs/apbs.h"
 
 #define IJK(i,j,k)  (((k)*(nx)*(ny))+((j)*(nx))+(i))
 #define INTERVAL(x,a,b) (((x) >= (a)) && ((x) <= (b)))
 
-VEMBED(rcsid="$Id: mergedx2.c 1350 2009-02-12 00:38:48Z yhuang01 $")
+VEMBED(rcsid="$Id: mergedx2.c 1615 2010-10-20 19:16:35Z sobolevnrm $")
 
 VPRIVATE int Vgrid_readDXhead(Vgrid *thee,
   const char *iodev, const char *iofmt, const char *thost, const char *fname);
@@ -125,7 +77,7 @@ int main(int argc, char **argv) {
     int i, j, k,spec,warn;
     int nx, ny, nz, count, numfnams;
 	
-    double pt[3],value, res;
+    double pt[3],value, res1, res2, res3, resx, resy, resz;
 	
     double xmin, ymin, zmin;
 	double xmax, ymax, zmax;
@@ -138,21 +90,25 @@ int main(int argc, char **argv) {
 	
     char *snam = "# main:  ";
     char outname[80];
-	
+
+	int ch, ind;
+	extern char *optarg;
+	extern int optind, opterr, optopt;
+
+
     Vgrid *grid, *mgrid;
 	
 	/* Set the default values */
 	spec = 0;
 	warn = 0;
-	res = 1.0;
+	res1 = 1.0;
+	res2 = 1.0;
+	res3 = 1.0;
 	xmin = ymin = zmin = 0.0;
 	xmax = ymax = zmax = 0.0;
 	sprintf(outname,"gridmerged.dx");
 	
 	/* Begin processing command line options */
-	int ch, ind;
-	extern char *optarg;
-	extern int optind, opterr, optopt;
 	
 	/* Check the invocation */
 	if(argc <= 1){ usage(); return 1; }
@@ -160,7 +116,11 @@ int main(int argc, char **argv) {
 	while ((ch = getopt(argc, argv, "r:b:o:s:h")) != -1) {
 		switch (ch) {
 			case 'r':
-				res = atof(optarg);
+				ind = optind - 1;
+				res1 = atof(argv[ind++]);
+				res2 = atof(argv[ind++]);
+				res3 = atof(argv[ind++]);
+				optind = ind;
 				break;
 			case 'b':
 				ind = optind - 1;
@@ -201,12 +161,12 @@ int main(int argc, char **argv) {
 	Vio_start();
 	
 	/* For now we only allow one resolution on all three axes */
-	double resx = res;
-	double resy = res;
-	double resz = res;
+	resx = res1;
+	resy = res2;
+	resz = res3;
 	
     /* *********** PREPARE MERGED GRID OBJECT ************* */
-    mgrid = Vgrid_ctor(nx, ny, nz, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, VNULL);
+    mgrid = Vgrid_ctor(0, 0, 0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, VNULL);
     mgrid->xmin = VLARGE; mgrid->xmax = -VLARGE;
     mgrid->ymin = VLARGE; mgrid->ymax = -VLARGE;
     mgrid->zmin = VLARGE; mgrid->zmax = -VLARGE;
@@ -226,7 +186,7 @@ int main(int argc, char **argv) {
         if( grid->zmin < mgrid->zmin ) mgrid->zmin = grid->zmin;
         if( grid->zmax > mgrid->zmax ) mgrid->zmax = grid->zmax;
 		
-		if( grid->hx > res || grid->hy > res || grid->hzed > res ) warn = 1;
+		if( grid->hx > res1 || grid->hy > res2 || grid->hzed > res3 ) warn = 1;
     }
 	
 	if(warn){
