@@ -2,53 +2,7 @@
  *  @file    smooth.c
  *  @author  Nathan Baker
  *  @brief   Convolve grid data with various filters
- *  @version $Id: smooth.c 1372 2009-05-28 13:38:12Z yhuang01 $
- *
- *  @attention
- *  @verbatim
- *
- * APBS -- Adaptive Poisson-Boltzmann Solver
- *
- * Nathan A. Baker (baker@biochem.wustl.edu)
- * Dept. of Biochemistry and Molecular Biophysics
- * Center for Computational Biology
- * Washington University in St. Louis
- *
- * Additional contributing authors listed in the code documentation.
- *
- * Copyright (c) 2002-2009, Washington University in St. Louis.
- * Portions Copyright (c) 2002-2009.  Nathan A. Baker
- * Portions Copyright (c) 1999-2002.  The Regents of the University of California.
- * Portions Copyright (c) 1995.  Michael Holst
- *
- * All rights reserved.
- * 
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions are met: 
- *
- * -  Redistributions of source code must retain the above copyright notice, this
- * list of conditions and the following disclaimer.  
- * 
- * - Redistributions in binary form must reproduce the above copyright notice,
- * this list of conditions and the following disclaimer in the documentation
- * and/or other materials provided with the distribution.
- * 
- * - Neither the name of Washington University in St. Louis nor the names of its
- * contributors may be used to endorse or promote products derived from this
- * software without specific prior written permission.
- * 
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
- * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
- * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
- * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
- * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
- * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
- * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
- * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. *
- * @endverbatim
+ *  @version $Id: smooth.c 1615 2010-10-20 19:16:35Z sobolevnrm $
  */
 
 #include "apbscfg.h"
@@ -62,7 +16,7 @@ typedef enum Smooth_Filter {
 } Smooth_Filter;
 
 
-VEMBED(rcsid="$Id: smooth.c 1372 2009-05-28 13:38:12Z yhuang01 $")
+VEMBED(rcsid="$Id: smooth.c 1615 2010-10-20 19:16:35Z sobolevnrm $")
 
 int gaussian(Vgrid *grid, double stddev, double bandwidth);
 
